@@ -15,12 +15,15 @@ class CloudFront:
     - Static content by extracting modified dates from static content.
 
     :param content_manager: challice_http_toolkit.ContentManager
+    :param app: Chalice or Blueprint
+    :param default_cache_control: Cache control to use if none specified
     :returns: CloudFront instance
     """
-    def __init__(self, content_manager:ContentManager, app:Union[Chalice, Blueprint]):
+    def __init__(self, content_manager:ContentManager, app:Union[Chalice, Blueprint], default_cache_control='no-cache'):
         self.__fsl = FileSystemLoader(content_manager.templates_dir)
         self.__cm = content_manager
         self.__app = app
+        self.__default_cache_control = default_cache_control
         self.__template_cache = {}
 
     def __template_calculate(self, filename:str, **kwargs) -> str:
@@ -80,6 +83,7 @@ class CloudFront:
         :returns: Chalice Response object
         """
         if self.__app.current_request is None:
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
 
         if_none_match = self.__app.current_request.headers.get('If-None-Match')
@@ -94,12 +98,12 @@ class CloudFront:
                 print(f'If-None-Match: {if_none_match} != {hsh}, Calling origin function')
                 r = self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
                 r.headers['ETag'] = hsh
-                if cache_control is not None:
-                    r.headers['Cache-Control'] = cache_control
+                r.headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
                 return r
         except Exception as e:
             print('Exception')
             traceback.print_exc()
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.html(self.__cm.render_template(filename, **kwargs), status_code=status_code, headers=headers)
 
     def static(self, filename:str, status_code:int=200, headers:Optional[dict]=None, cache_control:Optional[str]=None) -> Response:
@@ -114,6 +118,7 @@ class CloudFront:
         :returns: Chalice Response object
         """
         if self.__app.current_request is None:
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.static(filename, status_code=status_code, headers=headers)
 
         if_modified_since = self.__app.current_request.headers.get('If-Modified-Since')
@@ -132,12 +137,12 @@ class CloudFront:
                 print(f'If-Modified-Since: {mtime} > {if_modified_since}, Calling origin function')
                 r = self.__cm.static(filename, status_code=status_code, headers=headers)
                 r.headers['Last-Modified'] = mtime.strftime('%a, %d %b %Y %H:%M:%S GMT')
-                if cache_control is not None:
-                    r.headers['Cache-Control'] = cache_control
+                r.headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
                 return r
         except Exception as e:
             print('Exception')
             traceback.print_exc()
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.static(filename, status_code=status_code, headers=headers)
 
     def asset(self, get_asset:Callable[[],bytes], get_etag:Callable[[],str], status_code:int=200, headers:Optional[dict]=None, cache_control:Optional[str]=None) -> Response:
@@ -153,6 +158,7 @@ class CloudFront:
         :returns: Chalice Response object
         """
         if self.__app.current_request is None:
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.asset(get_asset(), status_code=status_code, headers=headers)
 
         if_none_match = self.__app.current_request.headers.get('If-None-Match')
@@ -168,10 +174,10 @@ class CloudFront:
                 print(f'If-None-Match: {if_none_match} != {hsh}, Calling origin function')
                 r = self.__cm.asset(get_asset(), status_code=status_code, headers=headers)
                 r.headers['ETag'] = hsh
-                if cache_control is not None:
-                    r.headers['Cache-Control'] = cache_control
+                r.headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
                 return r
         except Exception as e:
             print('Exception')
             traceback.print_exc()
+            headers['Cache-Control'] = cache_control if cache_control is not None else self.__default_cache_control
             return self.__cm.asset(get_asset(), status_code=status_code, headers=headers)
\ No newline at end of file
