@@ -10,6 +10,12 @@ import json
 from PIL import Image, UnidentifiedImageError
 
 class ContentManager:
+    ACCEPTS2PIL = {'image/jpeg': 'JPEG',
+                   'image/jpg': 'JPEG',
+                   'image/webp': 'WEBP',
+                   'image/png': 'PNG',
+                   'image/gif': 'GIF'}
+
     """
     Creates a ContentManager instance which allows rendering templates, returning static content
     and dynamic assets plus more. Generally after a ContentManager is called, set_static_handler_prefix()
@@ -33,7 +39,6 @@ class ContentManager:
                     p = os.path.join(dirpath, fn)
                     p = os.path.relpath(p, static_dir)
                     self.__allowed_static_files.append(p)
-        print(self.__allowed_static_files)
         self.env = jinja2.Environment(loader=jinja2.FileSystemLoader(templates_dir))
         self.__magic = magic if magic else Magic(mime=True)
         self.__app = app
@@ -70,15 +75,10 @@ class ContentManager:
         :returns: Converted image
         :raises: Exception if cant find matching type to convert to
         """
-        accepts2pil = {'image/jpeg': 'JPEG',
-                       'image/jpg': 'JPEG',
-                       'image/webp': 'WEBP',
-                       'image/png': 'PNG',
-                       'image/gif': 'GIF'}
         new_format = default
         for t in accepts.split(','):
-            if t in accepts2pil:
-                new_format = accepts2pil[t]
+            if t in self.ACCEPTS2PIL:
+                new_format = self.ACCEPTS2PIL[t]
                 break
         else:
             if default is None:
@@ -138,14 +138,13 @@ class ContentManager:
 
         print(f'[{filename}]: Was {content_type} {type(body)}')
         isBase64Encoded = False
-        if content_type.startswith('image/'):
+        if content_type in self.ACCEPTS2PIL:
             if self.__app.current_request:
                 accepts = self.__app.current_request.headers.get('accept', '')
                 if accepts:
                     body = self.convert_by_accepts(body, accepts)
                     content_type = self.__magic.from_buffer(body)
-            if not content_type == 'image/svg+xml':
-                isBase64Encoded = True
+            isBase64Encoded = True
         print(f'[{filename}]: Is {content_type} {type(body)}')
         h["Content-Type"] = content_type
         r = ResponseWithBinary(body=body, status_code=status_code, headers=h)
