@@ -1,7 +1,8 @@
 from requests_toolbelt import MultipartDecoder
-from chalice import Chalice
+from chalice import Chalice, Blueprint
+from typing import Union
 
-def ex_multipart(app:Chalice) -> dict:
+def ex_multipart(app:Union[Chalice,Blueprint]) -> dict:
     """
     Decodes content_type='multipart/form-data'  and returns a dictionary of parts in the format:
     {
