@@ -1,6 +1,5 @@
 from chalice import Response
 import os
-import base64
 
 class ResponseWithBinary(Response):
     """
@@ -13,8 +12,6 @@ class ResponseWithBinary(Response):
     def to_dict(self, binary_types=None) -> dict:
         response = super().to_dict(binary_types=binary_types)
         if self.isLocal:
-            if self.isBase64Encoded:
-                response['body'] = base64.b64decode(response['body'])
             response['isBase64Encoded'] = False
         elif self.isBase64Encoded:
             response['isBase64Encoded'] = True
